@@ -41,10 +41,6 @@ import (
 // with a zero length array (not nil) when they are returned.
 var chkDiv = [...]string{"definitions", "libraries", "attributes", "providers", "resources", "templates", "root_files", "files"}
 
-// VersionStrings is a type to make version strings with the format "x.y.z"
-// sortable.
-type VersionStrings []string
-
 // The Cookbook struct holds an array of cookbook versions, which is where the
 // run lists, definitions, attributes, etc. are.
 type Cookbook struct {
@@ -80,68 +76,6 @@ type CookbookVersion struct {
 	cookbookID   int32
 }
 
-const (
-	CookbookNotFound int = iota
-	CookbookNoVersion
-)
-
-var cookbookVerErr = map[int]string{CookbookNotFound: "not found", CookbookNoVersion: "no version"}
-
-type versionConstraint gversion.Constraints
-
-type versionConstraintError struct {
-	ViolationType    int
-	ParentCookbook   string
-	ParentConstraint string
-	ParentVersion    string
-	Cookbook         string
-	Constraint       string
-}
-
-func (v versionConstraint) Satisfied(head, tail *depgraph.Noun) (bool, error) {
-	tMeta := tail.Meta.(*depMeta)
-	var headVersion string
-	var headConstraint string
-	if head.Meta != nil {
-		headVersion = head.Meta.(*depMeta).version
-		headConstraint = head.Meta.(*depMeta).constraint.String()
-	}
-
-	verr := &versionConstraintError{ParentCookbook: head.Name, ParentVersion: headVersion, ParentConstraint: headConstraint, Cookbook: tail.Name, Constraint: v.String()}
-
-	if tMeta.notFound {
-		verr.ViolationType = CookbookNotFound
-		return false, verr
-	}
-	if tMeta.version == "" {
-		verr.ViolationType = CookbookNoVersion
-		// but what constraint isn't met?
-		cb, _ := Get(tail.Name)
-		if cb != nil {
-			badver := cb.badConstraints(v)
-			verr.Constraint = strings.Join(badver, ",")
-		}
-		return false, verr
-	}
-
-	return true, nil
-}
-
-func (v versionConstraint) String() string {
-	return gversion.Constraints(v).String()
-}
-
-type depMeta struct {
-	version    string
-	constraint versionConstraint
-	notFound   bool
-	noVersion  bool
-}
-
-type DependsError struct {
-	depErr *depgraph.ConstraintError
-}
-
 /* Cookbook methods and functions */
 
 // GetName returns the name of the cookbook.
@@ -631,45 +565,6 @@ func (cbv *CookbookVersion) getDependencies(g *depgraph.Graph, nodes map[string]
 	}
 }
 
-func constraintPresent(constraints versionConstraint, cons string) bool {
-	for _, c := range constraints {
-		if c.String() == cons {
-			// already in here, bail
-			return true
-		}
-	}
-	return false
-}
-
-func appendConstraint(constraints *versionConstraint, cons string) {
-	if constraintPresent(*constraints, cons) {
-		return
-	}
-	newcon, _ := gversion.NewConstraint(cons)
-	*constraints = append(*constraints, newcon...)
-}
-
-func checkDependency(node *depgraph.Noun, cbName string) (*depgraph.Dependency, int, bool) {
-	depName := fmt.Sprintf("%s-%s", node.Name, cbName)
-	for i, d := range node.Deps {
-		if depName == d.Name {
-			return d, i, true
-		}
-	}
-	return nil, -1, false
-}
-
-func splitConstraint(constraint string) (string, string, error) {
-	t1 := strings.Split(constraint, " ")
-	if len(t1) != 2 {
-		err := fmt.Errorf("Constraint '%s' was not well-formed.", constraint)
-		return "", "", err
-	}
-	op := t1[0]
-	ver := t1[1]
-	return op, ver, nil
-}
-
 func (c *Cookbook) infoHashBase(numResults interface{}, constraint string) map[string]interface{} {
 	cbHash := make(map[string]interface{})
 	cbHash["url"] = util.ObjURL(c)
@@ -890,42 +785,6 @@ func (c *Cookbook) DoesVersionExist(cbVersion string) (bool, util.Gerror) {
 	return found, nil
 }
 
-func extractVerNums(cbVersion string) (maj, min, patch int64, err util.Gerror) {
-	if _, err = util.ValidateAsVersion(cbVersion); err != nil {
-		return 0, 0, 0, err
-	}
-	nums := strings.Split(cbVersion, ".")
-	if len(nums) < 2 && len(nums) > 3 {
-		err = util.Errorf("incorrect number of numbers in version string '%s': %d", cbVersion, len(nums))
-		return 0, 0, 0, err
-	}
-	var vt int64
-	var nerr error
-	vt, nerr = strconv.ParseInt(nums[0], 0, 64)
-	if nerr != nil {
-		err = util.Errorf(nerr.Error())
-		return 0, 0, 0, err
-	}
-	maj = vt
-	vt, nerr = strconv.ParseInt(nums[1], 0, 64)
-	if nerr != nil {
-		err = util.Errorf(nerr.Error())
-		return 0, 0, 0, err
-	}
-	min = vt
-	if len(nums) == 3 {
-		vt, nerr = strconv.ParseInt(nums[2], 0, 64)
-		if nerr != nil {
-			err = util.Errorf(nerr.Error())
-			return 0, 0, 0, err
-		}
-		patch = vt
-	} else {
-		patch = 0
-	}
-	return maj, min, patch, nil
-}
-
 func (c *Cookbook) deleteHashes(fhashes []string) {
 	/* And remove the unused hashes. Currently, sigh, this involves checking
 	 * every cookbook. Probably will be easier with an actual database, I
@@ -1301,224 +1160,3 @@ func (cbv *CookbookVersion) RecipeList() ([]string, util.Gerror) {
 	}
 	return recipes, nil
 }
-
-/* Version string functions to implement sorting */
-
-func (v VersionStrings) Len() int {
-	return len(v)
-}
-
-func (v VersionStrings) Swap(i, j int) {
-	v[i], v[j] = v[j], v[i]
-}
-
-func (v VersionStrings) Less(i, j int) bool {
-	return versionLess(v[i], v[j])
-}
-
-func versionLess(verA, verB string) bool {
-	/* Chef cookbook versions are always to be in the form x.y.z (with x.y
-	 * also allowed. This simplifies things a bit. */
-
-	/* Easy comparison. False if they're equal. */
-	if verA == verB {
-		return false
-	}
-
-	/* Would caching the split strings ever be particularly worth it? */
-	iVer := strings.Split(verA, ".")
-	jVer := strings.Split(verB, ".")
-
-	for q := 0; q < 3; q++ {
-		/* If one of them doesn't actually exist, then obviously the
-		 * other is bigger, and we're done. Of course this should only
-		 * happen with the 3rd element. */
-		if len(iVer) < q+1 {
-			return true
-		} else if len(jVer) < q+1 {
-			return false
-		}
-
-		ic := iVer[q]
-		jc := jVer[q]
-
-		/* Otherwise, see if they're equal. If they're not, return the
-		 * result of x < y. */
-		ici, _ := strconv.Atoi(ic)
-		jci, _ := strconv.Atoi(jc)
-		if ici != jci {
-			return ici < jci
-		}
-	}
-	return false
-}
-
-/* Compares a version number against a constraint, like version 1.2.3 vs.
- * ">= 1.0.1". In this case, 1.2.3 passes. It would not satisfy "= 1.2.0" or
- * "< 1.0", though. */
-
-func verConstraintCheck(verA, verB, op string) string {
-	switch op {
-	case "=":
-		if verA == verB {
-			return "ok"
-		} else if versionLess(verA, verB) {
-			/* If we want equality and verA is less than
-			 * version b, since the version list is sorted
-			 * in descending order we've missed our chance.
-			 * So, break out. */
-			return "break"
-		} else {
-			return "skip"
-		}
-	case ">":
-		if verA == verB || versionLess(verA, verB) {
-			return "break"
-		}
-		return "ok"
-	case "<":
-		/* return skip here because we might find what we want
-		 * later. */
-		if verA == verB || !versionLess(verA, verB) {
-			return "skip"
-		}
-		return "ok"
-	case ">=":
-		if !versionLess(verA, verB) {
-			return "ok"
-		}
-		return "break"
-	case "<=":
-		if verA == verB || versionLess(verA, verB) {
-			return "ok"
-		}
-		return "skip"
-	case "~>":
-		/* only check pessimistic constraints if they can
-		 * possibly be valid. */
-		if versionLess(verA, verB) {
-			return "break"
-		}
-		var upperBound string
-		pv := strings.Split(verB, ".")
-		if len(pv) == 3 {
-			uver, _ := strconv.Atoi(pv[1])
-			uver++
-			upperBound = fmt.Sprintf("%s.%d", pv[0], uver)
-		} else {
-			uver, _ := strconv.Atoi(pv[0])
-			uver++
-			upperBound = fmt.Sprintf("%d.0", uver)
-		}
-		if !versionLess(verA, verB) && versionLess(verA, upperBound) {
-
-			return "ok"
-		}
-		return "skip"
-	default:
-		return "invalid"
-	}
-}
-
-func (v *versionConstraintError) Error() string {
-	// assemble error message from what we have
-	msg := fmt.Sprintf("%s: %s %s %s %s", cookbookVerErr[v.ViolationType], v.ParentCookbook, v.ParentVersion, v.Cookbook, v.Constraint)
-	return msg
-}
-
-func (v *versionConstraintError) String() string {
-	return v.Error()
-}
-
-func (d *DependsError) Error() string {
-	errMap := d.ErrMap()
-	return errMap["message"].(string)
-}
-
-func (d *DependsError) String() string {
-	return d.Error()
-}
-
-func (d *DependsError) ErrMap() map[string]interface{} {
-	errMap := make(map[string]interface{})
-
-	allMsgs := make([]string, 0)
-	notFound := make([]string, 0)
-	mostConstrained := make([]string, 0)
-	noVersion := make([]string, 0)
-	unsatisfiable := make([]string, 0)
-
-	for _, ce := range d.depErr.Violations {
-		var vMsg string
-		verr := ce.Err.(*versionConstraintError)
-		var unsat bool
-		if verr.ParentCookbook != "^runlist_root^" {
-			unsat = true
-			unsatisfiable = append(unsatisfiable, fmt.Sprintf("(%s %s)", verr.ParentCookbook, verr.ParentConstraint))
-		}
-		if verr.ViolationType == CookbookNotFound {
-			notFound = append(notFound, verr.Cookbook)
-		} else {
-			if unsat {
-				cb, _ := Get(verr.Cookbook)
-				var cbv *CookbookVersion
-				if cb != nil {
-					cbv = cb.LatestVersion()
-				}
-				var p, c string
-				if cbv != nil {
-					c = fmt.Sprintf("%s = %s", cbv.CookbookName, cbv.Version)
-					depList := cbv.Metadata["dependencies"].(map[string]interface{})
-					if dp, ok := depList[verr.ParentCookbook]; ok {
-						p = fmt.Sprintf("(%s %s)", verr.ParentCookbook, dp)
-					}
-				} else {
-					// something is very bad, try our best
-					// to recover
-					p = fmt.Sprintf("%s %s", verr.ParentCookbook, verr.ParentConstraint)
-					c = fmt.Sprintf("%s %s", verr.Cookbook, verr.Constraint)
-				}
-				mostConstrained = append(mostConstrained, fmt.Sprintf("%s -> [%s]", c, p))
-
-			} else {
-				noVersion = append(noVersion, fmt.Sprintf("(%s %s)", verr.Cookbook, verr.Constraint))
-			}
-		}
-		// craft our message:
-		if unsat {
-			var doesntExist string
-			if verr.ViolationType == CookbookNotFound {
-				doesntExist = ", which does not exist,"
-			}
-			vMsg = fmt.Sprintf("Unable to satisfy constraints on package %s%s due to solution constraint (%s %s). Solution constraints that may result in a constraint on %s: [(%s = %s) -> (%s %s)]", verr.Cookbook, doesntExist, verr.ParentCookbook, verr.ParentConstraint, verr.Cookbook, verr.ParentCookbook, verr.ParentVersion, verr.Cookbook, verr.Constraint)
-		} else {
-			vMsg = "Run list contains invalid items:"
-			if len(notFound) > 0 {
-				var werd string
-				if len(notFound) == 1 {
-					werd = "cookbook"
-				} else {
-					werd = "cookbooks"
-				}
-				vMsg = fmt.Sprintf("%s no such %s %s", vMsg, werd, strings.Join(notFound, ", "))
-			}
-			if len(noVersion) > 0 {
-				vMsg = fmt.Sprintf("%s no versions match the constraints on cookbook %s", vMsg, strings.Join(noVersion, ", "))
-			}
-			vMsg = fmt.Sprintf("%s.", vMsg)
-		}
-		allMsgs = append(allMsgs, vMsg)
-	}
-	msg := strings.Join(allMsgs, "\n")
-	errMap["message"] = msg
-
-	errMap["non_existent_cookbooks"] = notFound
-	if len(unsatisfiable) > 0 {
-		errMap["unsatisfiable_run_list_item"] = strings.Join(unsatisfiable, ", ")
-		errMap["most_constrained_cookbooks"] = mostConstrained
-	} else {
-		errMap["cookbooks_with_no_versions"] = noVersion
-	}
-
-	return errMap
-}
