@@ -206,6 +206,10 @@ func main() {
 		startReportPurge()
 	}
 
+	if config.Config.PurgeSandboxesDur != 0 {
+		startSandboxPurge()
+	}
+
 	/* Create default clients and users. Currently chef-validator,
 	 * chef-webui, and admin. */
 	createDefaultActors()
@@ -361,6 +365,19 @@ func (h *interceptHandler) ServeHTTP(w http.ResponseWriter, r *http.Request) {
 	apiInfo := fmt.Sprintf("flavor=osc;version:%s;goiardi=%s", config.ChefVersion, config.Version)
 	w.Header().Set("X-Ops-API-Info", apiInfo)
 
+	apiver := r.Header.Get("X-Ops-Server-API-Version")
+	if matchSupportedVersion(apiver) {
+		w.Header().Set(
+			"X-Ops-Server-API-Version",
+			fmt.Sprintf(
+				`{"min_version": "%s", "max_version": "%s", "request_version": "%s", "response_version": "%s"}`,
+				config.MinAPIVersion,
+				config.MaxAPIVersion,
+				apiver,
+				apiver,
+			),
+		)
+	}
 	userID := r.Header.Get("X-OPS-USERID")
 	if rs := r.Header.Get("X-Ops-Request-Source"); rs == "web" {
 		/* If use-auth is on and disable-webui is on, and this is a
@@ -816,6 +833,21 @@ func startReportPurge() {
 	}()
 }
 
+func startSandboxPurge() {
+	go func() {
+		// check for sandboxes to purge every hour
+		ticker := time.NewTicker(time.Hour)
+		for _ = range ticker.C {
+			del, err := sandbox.Purge(config.Config.PurgeSandboxesDur)
+			if err != nil {
+				logger.Errorf("Purging sandboxes (somehow) had an error: %s", err.Error())
+			} else {
+				logger.Debugf("Purged %d sandboxes", del)
+			}
+		}
+	}()
+}
+
 func startNodeStatusPurge() {
 	// don't do it if there aren't going to be node statuses to purge
 	if !config.Config.UseSerf || config.Config.PurgeNodeStatusDur == 0 {
@@ -916,3 +948,12 @@ func initGeneralStatsd(metricsBackend met.Backend) {
 		}
 	}()
 }
+
+func matchSupportedVersion(ver string) bool {
+	for _, v := range config.SupportedAPIVersions {
+		if ver == v {
+			return true
+		}
+	}
+	return false
+}
